==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressPodTemplateBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressPodTemplateBuilder extends ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl<ACMEChallengeSolverHTTP01IngressPodTemplateBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodTemplate,ACMEChallengeSolverHTTP01IngressPodTemplateBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressPodTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodTemplate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplate instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressPodTemplate build() {
    ACMEChallengeSolverHTTP01IngressPodTemplate buildable = new ACMEChallengeSolverHTTP01IngressPodTemplate(fluent.getMetadata(),fluent.getSpec());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressPodTemplateBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressPodTemplateBuilder extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<ACMEChallengeSolverHTTP01IngressPodTemplateBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodTemplate,ACMEChallengeSolverHTTP01IngressPodTemplateBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressPodTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodTemplate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodTemplate());

    if (instance != null) {
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplate instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodTemplate());

    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressPodTemplate build() {
    ACMEChallengeSolverHTTP01IngressPodTemplate buildable = new ACMEChallengeSolverHTTP01IngressPodTemplate(fluent.buildMetadata(),fluent.buildSpec());
    return buildable;
  }
  
}
